package com.aucma.base.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.aucma.base.mapper.BaseProcessStationMapper;
import com.aucma.base.domain.BaseProcessStation;
import com.aucma.base.service.IBaseProcessStationService;

/**
 * 生产工序/工位信息Service业务层处理
 * 
 * @author Yinq
 * @date 2023-11-14
 */
@Service
public class BaseProcessStationServiceImpl implements IBaseProcessStationService 
{
    @Autowired
    private BaseProcessStationMapper baseProcessStationMapper;

    /**
     * 查询生产工序/工位信息
     * 
     * @param objId 生产工序/工位信息主键
     * @return 生产工序/工位信息
     */
    @Override
    public BaseProcessStation selectBaseProcessStationByObjId(Long objId)
    {
        return baseProcessStationMapper.selectBaseProcessStationByObjId(objId);
    }

    /**
     * 查询生产工序/工位信息列表
     * 
     * @param baseProcessStation 生产工序/工位信息
     * @return 生产工序/工位信息
     */
    @Override
    public List<BaseProcessStation> selectBaseProcessStationList(BaseProcessStation baseProcessStation)
    {
        return baseProcessStationMapper.selectBaseProcessStationList(baseProcessStation);
    }

    /**
     * 新增生产工序/工位信息
     * 
     * @param baseProcessStation 生产工序/工位信息
     * @return 结果
     */
    @Override
    public int insertBaseProcessStation(BaseProcessStation baseProcessStation)
    {
        return baseProcessStationMapper.insertBaseProcessStation(baseProcessStation);
    }

    /**
     * 修改生产工序/工位信息
     * 
     * @param baseProcessStation 生产工序/工位信息
     * @return 结果
     */
    @Override
    public int updateBaseProcessStation(BaseProcessStation baseProcessStation)
    {
        return baseProcessStationMapper.updateBaseProcessStation(baseProcessStation);
    }

    /**
     * 批量删除生产工序/工位信息
     * 
     * @param objIds 需要删除的生产工序/工位信息主键
     * @return 结果
     */
    @Override
    public int deleteBaseProcessStationByObjIds(Long[] objIds)
    {
        return baseProcessStationMapper.deleteBaseProcessStationByObjIds(objIds);
    }

    /**
     * 删除生产工序/工位信息信息
     * 
     * @param objId 生产工序/工位信息主键
     * @return 结果
     */
    @Override
    public int deleteBaseProcessStationByObjId(Long objId)
    {
        return baseProcessStationMapper.deleteBaseProcessStationByObjId(objId);
    }
}
