package com.aucma.base.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.aucma.common.utils.DateUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.aucma.common.annotation.Log;
import com.aucma.common.core.controller.BaseController;
import com.aucma.common.core.domain.AjaxResult;
import com.aucma.common.enums.BusinessType;
import com.aucma.base.domain.BaseProcessStation;
import com.aucma.base.service.IBaseProcessStationService;
import com.aucma.common.utils.poi.ExcelUtil;
import com.aucma.common.core.page.TableDataInfo;

/**
 * 生产工序/工位信息Controller
 *
 * @author Yinq
 * @date 2023-11-14
 */
@RestController
@RequestMapping("/base/processStation" )
public class BaseProcessStationController extends BaseController {
    @Autowired
    private IBaseProcessStationService baseProcessStationService;

    /**
     * 查询生产工序/工位信息列表
     */
    @PreAuthorize("@ss.hasPermi('base:processStation:list')" )
    @GetMapping("/list" )
    public TableDataInfo list(BaseProcessStation baseProcessStation) {
        startPage();
        List<BaseProcessStation> list = baseProcessStationService.selectBaseProcessStationList(baseProcessStation);
        return getDataTable(list);
    }

    /**
     * 导出生产工序/工位信息列表
     */
    @PreAuthorize("@ss.hasPermi('base:processStation:export')" )
    @Log(title = "生产工序/工位信息" , businessType = BusinessType.EXPORT)
    @PostMapping("/export" )
    public void export(HttpServletResponse response, BaseProcessStation baseProcessStation) {
        List<BaseProcessStation> list = baseProcessStationService.selectBaseProcessStationList(baseProcessStation);
        ExcelUtil<BaseProcessStation> util = new ExcelUtil<BaseProcessStation>(BaseProcessStation. class);
        util.exportExcel(response, list, "生产工序/工位信息数据" );
    }

    /**
     * 获取生产工序/工位信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('base:processStation:query')" )
    @GetMapping(value = "/{objId}" )
    public AjaxResult getInfo(@PathVariable("objId" ) Long objId) {
        return success(baseProcessStationService.selectBaseProcessStationByObjId(objId));
    }

    /**
     * 新增生产工序/工位信息
     */
    @PreAuthorize("@ss.hasPermi('base:processStation:add')" )
    @Log(title = "生产工序/工位信息" , businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BaseProcessStation baseProcessStation) {
        baseProcessStation.setCreatedBy(getUsername());
        baseProcessStation.setCreatedTime(DateUtils.getNowDate());
        return toAjax(baseProcessStationService.insertBaseProcessStation(baseProcessStation));
    }

    /**
     * 修改生产工序/工位信息
     */
    @PreAuthorize("@ss.hasPermi('base:processStation:edit')" )
    @Log(title = "生产工序/工位信息" , businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BaseProcessStation baseProcessStation) {
        baseProcessStation.setUpdatedBy(getUsername());
        baseProcessStation.setUpdatedTime(DateUtils.getNowDate());
        return toAjax(baseProcessStationService.updateBaseProcessStation(baseProcessStation));
    }

    /**
     * 删除生产工序/工位信息
     */
    @PreAuthorize("@ss.hasPermi('base:processStation:remove')" )
    @Log(title = "生产工序/工位信息" , businessType = BusinessType.DELETE)
    @DeleteMapping("/{objIds}" )
    public AjaxResult remove(@PathVariable Long[] objIds) {
        return toAjax(baseProcessStationService.deleteBaseProcessStationByObjIds(objIds));
    }
}
